<?php
/**
 * FuzeWorks Forms Library
 *
 * The FuzeWorks PHP FrameWork
 *
 * Copyright (C) 2013-${YEAR} i15
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * @author    i15
 * @copyright Copyright (c) 2013 - ${YEAR}, i15. (http://i15.nl)
 * @license   https://opensource.org/licenses/MIT MIT License
 *
 * @link  https://i15.nl
 * @since Version 1.3.0
 *
 * @version Version 1.3.0
 */

namespace FuzeWorks\Forms\Fields;
use FuzeWorks\Forms\Field;

class ButtonField extends Field
{

    protected string $type = "button";

    /**
     * The submit button name
     *
     * @var string|null
     */
    protected ?string $buttonText = null;
    protected array $classNames = ["btn", "btn-primary"];
    protected ?string $onClick = null;

    /**
     * @inheritDoc
     */
    protected function validateField(): bool
    {
        return true;
    }

    public function setButtonText(string $text): self
    {
        $this->buttonText = $text;
        return $this;
    }

    public function onClick(string $text): self
    {
        $this->onClick = $text;
        return $this;
    }

    /**
     * @inheritDoc
     */
    public function generateHtml(): string
    {
        $id = "id='".$this->getId()."'";
        $name = "name='".$this->getName()."'";
        $value = is_null($this->buttonText) ? "value='".ucfirst($this->getName())."'" : "value='".$this->buttonText."'";
        $class = "class='".implode(" ", $this->classNames)."'";
        $onClick = !is_null($this->onClick) ? "onclick='" . $this->onClick . "'" : "";

        return "<input $class type='$this->type' $id $name $value $onClick>";
    }
}