<?php
/**
 * FuzeWorks Forms Library
 *
 * The FuzeWorks PHP FrameWork
 *
 * Copyright (C) 2013-${YEAR} i15
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * @author    i15
 * @copyright Copyright (c) 2013 - ${YEAR}, i15. (http://i15.nl)
 * @license   https://opensource.org/licenses/MIT MIT License
 *
 * @link  https://i15.nl
 * @since Version 1.3.0
 *
 * @version Version 1.3.0
 */

namespace FuzeWorks\Forms\Fields;

class TextAreaField extends TextField
{

    public const WRAP_HARD = 1;
    public const WRAP_SOFT = 2;

    protected int $cols = 0;
    protected int $rows = 0;
    protected int $wrap = 0;


    /**
     * How many columns the field should have
     *
     * @param int $colAmount
     * @return $this
     */
    public function columns(int $colAmount): self
    {
        $this->cols = $colAmount;
        return $this;
    }

    /**
     * How many rows the field should have.
     *
     * @param int $rowAmount
     * @return $this
     */
    public function rows(int $rowAmount): self
    {
        $this->rows = $rowAmount;
        return $this;
    }

    /**
     * Which way to wrap text in the TextArea.
     *
     * Can be TextAreaField::WRAP_HARD or TextAreaField::WRAP_SOFT.
     *
     * @param int $wrapType
     * @return $this
     */
    public function wrap(int $wrapType): self
    {
        $this->wrap = $wrapType;
        return $this;
    }

    /**
     * @inheritDoc
     */
    public function generateHtml(): string
    {
        $id = "id='".$this->getId()."'";
        $name = "name='".$this->getName()."'";
        $lock = $this->lock ? "disabled" : "";
        $placeholder = !is_null($this->placeholder) ? "placeholder='".$this->placeholder."'" : "";
        $maxLength = $this->maxLength > 0 ? "maxlength='".$this->maxLength."'" : "";
        $minLength = $this->minLength > 0 ? "minlength='".$this->minLength."'" : "";
        $rows = $this->rows > 0 ? "rows='".$this->rows."'" : "";
        $cols = $this->cols > 0 ? "cols='".$this->cols."'" : "";
        $wrap = $this->wrap == self::WRAP_HARD ? "wrap='hard'" : "wrap='soft'";
        $class = "class='".implode(" ", $this->classNames)."'";

        return "<textarea $class $id $name $lock $placeholder $maxLength $minLength $rows $cols $wrap>$this->value</textarea>";

    }
}